#!/bin/sh
# Detect older CP package and prevent upgrade on Linux

MYPKGNAME=WSES_CachingProxy

v="`rpm -q ${MYPKGNAME} --queryformat %{VERSION}\\\n 2>&1 | sed -n -e /^[23456]\.[0156]/p`"
if [ "$v" != "" ] ; then
	bad="$bad ${MYPKGNAME}"
fi


if [ "$bad" != "" ]; then
        printf "${MYPKGNAME} cannot be installed because a\n"
        printf "previous version of ${MYPKGNAME} is already installed.\n"
	exit 1
fi
# Check if we can run sed since it's needed for setting up the
# configuration files and start/stop script.  This should really
# be in Requires: but SuSE 6.0's base package doesn't list sed
# in it's Provides: so this package will fail the dependency
# checks on SuSE 6.0 if we list it in the Requires: line.
#
sed  > /dev/null 2>&1
if [ $? = 127 ] ; then
  echo " \
The utility sed could not be found.  sed is required for
setting up the configuration files.  Please either install
sed or correct PATH so it can be found and restart the
installation."
  exit 1
fi
# Check to see if the proxy is running, abort if true
pid=`ps -e | grep ibmproxy |grep -v "grep ibmproxy" | awk '{ print $1 }'`
if [ X"${pid}" != X"" ]
then
   printf "\n*******************************************\n"
   printf   "Please stop the ibmproxy before continuing.\n" 
   printf   "Operation aborted.\n" 
   printf   "*******************************************\n\n"
   exit 1
fi
# from aix script - may need something different to make common on all unixes
#ps -eaf | grep ${DAEMON_NAME} | awk ' { if ($8 == "/opt/IBMWTE/usr/internet/sbin/${DAEMON_NAME}" || $8 == "/opt/ibm/edge/cp/sbin/${DAEMON_NAME}" || $8 == "${DAEMON_NAME}" || $8 == "/usr/sbin/ibmproxy") print $2 }' | xargs kill -9 > /dev/null 2>&1
# Save all files in a directory
save_files ()
{
FROM_DIR=$1
DEL_FILE=$2
shift 2
for i in $*
do
   if [ -d ${FROM_DIR} ]
   then
	if [ -f ${FROM_DIR}/${i} ]
	then
		cp -p ${FROM_DIR}/${i} ${oldfiles_dir}/${i}.${DATE_SFX}
		cp -fp ${FROM_DIR}/${i} ${oldfiles_dir}
		if [ $? -eq 0 ]
		then
			if [ "${DEL_FILE}" = "TRUE" ]
			then
				rm -f ${FROM_DIR}/${i}
			fi
			COPYMADE="Y"
		else
			ERROR_COPYING="Y"
		fi
	fi
   fi
done
}

# Search a directory list for a copy of the file and save the first one found
save_file_in_dirs ()
{
NOT_FOUND="TRUE"
file_to_save=$1
shift
for dir in $*
do
   if [ -d ${dir} ]	
   then
	if [ ${NOT_FOUND} = "TRUE" -a -f ${dir}/$file_to_save ]
	then
	   NOT_FOUND="FALSE"
	   if [ ${dir} != ${oldfiles_dir} ]
	   then
		cp -p ${dir}/${file_to_save} ${oldfiles_dir}/${file_to_save}.${DATE_SFX}
		cp -fp ${dir}/${file_to_save} $oldfiles_dir
		if [ $? -eq 0 ]
		then
			FILECOPYMADE="Y"
		else
			ERROR_COPYING="Y"
		fi
	   fi
	fi
   fi
done
}

save_dirs ()
{
FROM_DIR=$1
DEL_DIR=$2
shift 2
for i in $*
do
	if [ -d ${FROM_DIR}/${i} ]
	then
		# On Linux, when copying directories, links within them are
		# copied as links; use -L to stop that
		if [ `uname` = "Linux" ]
		then
			cflags="-rLfp"
		else
			cflags="-rfp"
		fi

		cp ${cflags} ${FROM_DIR}/${i} ${oldfiles_dir}/${i}.${DATE_SFX}
		cp ${cflags} ${FROM_DIR}/${i} ${oldfiles_dir}

		if [ $? -eq 0 ]
		then
			if [ "${DEL_DIR}" = "TRUE" ]
			then
				rm -rf ${FROM_DIR}/${i}
			fi
			COPYMADE=Y
		else
			ERROR_COPYING="Y"
		fi
	fi
done
}


WES_HOME=/opt/ibm/edge
COMPONENT=cp
APP_HOME=$WES_HOME/$COMPONENT
oldfiles_dir=$WES_HOME/oldfiles/$COMPONENT

OLD_APPHOME="/opt/IBMWTE/usr/internet"
old_oldfiles="${OLD_APPHOME}/server_root/oldfiles"

AIX_GA35="/usr/lpp/internet"	# used for AIX only
aixga35_oldfiles=${AIX_GA35}/server_root/oldfiles


COPYMADE="N"
FILECOPYMADE="N"
DIRCOPYMADE="N"
ERROR_COPYING="N"

# These values are used to indicate if a file should be deleted
# after it is saved. Normally, generated files are deleted.
GENERATED_FILE="TRUE"
INSTALLED_FILE="FALSE"

if [ `uname` = "Linux" ]
then
	DATE=/bin/date
else
	DATE=/usr/bin/date
fi
DATE_SFX=`$DATE '+%y''%m''%d''%H''%M''%S'`

if [ ! -d ${oldfiles_dir} ]
then
	mkdir -p ${oldfiles_dir}
fi
# Save current config files before uninstalling

save_files /etc ${INSTALLED_FILE} socks.conf

# These files should have links in /etc

file_list="pac.conf pacpolicy.conf paccp.conf"
for filename in $file_list
do
	save_file_in_dirs $filename /etc ${APP_HOME}/etc
done

# Save webadmin files as a group
save_files ${APP_HOME}/server_root/protect ${INSTALLED_FILE} \
		webadmin.group webadmin.passwd webadmin.passwd.bak

# Split the cyberpatrol files into installed file(s) and generated files,
# because the generated files should be deleted on uninstall. 
save_files ${APP_HOME}/server_root/filter/cyberpatrol ${INSTALLED_FILE} \
		setup_state 

save_files ${APP_HOME}/server_root/filter/cyberpatrol ${GENERATED_FILE} \
		.cpauthinit registration.data

# File used for content distribution
save_files ${APP_HOME}/server_root/data ${GENERATED_FILE} mappingtbl

# set copymade to any "YES" result 
if [ "$COPYMADE" = "Y" -o "$FILECOPYMADE" = "Y" -o "$DIRCOPYMADE" = "Y" ]; then
	COPYMADE="Y"
fi
if [ ${ERROR_COPYING} = "Y" ]; then
	echo ""
	echo "Error copying configuration files to ${oldfiles_dir},"
	echo "not all files saved."
	echo ""
elif [ ${COPYMADE} = "Y" ]; then
	echo ""
	echo "Configuration files have been saved in ${oldfiles_dir}"
	echo ""
fi
exit 0
